@@ -1,9 +1,10 @@
 // vim: tw=80
 
-use std::env;
-use std::path::PathBuf;
-
+#[cfg(target_os = "freebsd")]
 fn main() {
+    use std::env;
+    use std::path::PathBuf;
+
     println!("cargo:rustc-link-lib=geom");
     let bindings = bindgen::Builder::default()
         .header("/usr/include/libgeom.h")
@@ -21,3 +22,11 @@ fn main() {
         .expect("Couldn't write bindings!");
 }
 
+#[cfg(not(target_os = "freebsd"))]
+fn main() {
+    // If we're building not on FreeBSD, there's no way the build can succeed.
+    // This probably means we're building docs on docs.rs, so set this config
+    // variable.  We'll use it to stub out the crate well enough that
+    // freebsd-libgeom's docs can build.
+    println!("cargo:rustc-cfg=crossdocs");
+}
