@@ -4,6 +4,8 @@
 //! These are raw, `unsafe` FFI bindings.  Here be dragons!  You probably
 //! shouldn't use this crate directly.  Instead, you should use the
 //! [`freebsd-libgeom`](https://crates.io/crates/freebsd-libgeom) crate.
+#![cfg_attr(crossdocs, doc="")]
+#![cfg_attr(crossdocs, doc="These docs are just stubs!  Don't trust them.")]
 
 // bindgen generates some unconventional type names
 #![allow(non_camel_case_types)]
@@ -14,4 +16,10 @@
 // https://github.com/rust-lang/rust-bindgen/issues/1651
 #![cfg_attr(test, allow(deref_nullptr))]
 
+#[cfg(not(crossdocs))]
 include!(concat!(env!("OUT_DIR"), "/bindings.rs"));
+
+#[cfg(crossdocs)]
+mod fakes;
+#[cfg(crossdocs)]
+pub use fakes::*;
